@@ -3,13 +3,14 @@
 #include "clearlooks_types.h"
 
 #include "support.h"
+#include <ge-support.h>
 
 #include <cairo.h>
 
 #define M_PI 3.14159265358979323846
 
 void
-clearlooks_rounded_rectectangle (cairo_t *cr,
+clearlooks_rounded_rectangle (cairo_t *cr,
                                  double x, double y, double w, double h,
                                  double radius, uint8 corners)
 {
@@ -205,6 +206,29 @@ clearlooks_draw_highlight_and_shade (cairo_t *cr,
 	cairo_restore (cr);
 }
 
+static void
+clearlooks_draw_gripdots (cairo_t *cr, int x, int y,
+                          int width, int height, int xr, int yr,
+                          float contrast)
+{
+	int i, j;
+	int xoff, yoff;
+
+	for ( i = 0; i < xr; i++ ) {
+		for ( j = 0; j < yr; j++ ) {
+			xoff = x -(xr * 3 / 2) + 3 * i;
+			yoff = y -(yr * 3 / 2) + 3 * j; 
+			
+			cairo_rectangle (cr, width/2+0.5+xoff, height/2+0.5+yoff, 2, 2);
+			cairo_set_source_rgba (cr, 1., 1., 1., 0.8+contrast);
+			cairo_fill (cr);
+			cairo_rectangle (cr, width/2+0.5+xoff, height/2+0.5+yoff, 1, 1);
+			cairo_set_source_rgba (cr, 0, 0, 0, 0.2+contrast);
+			cairo_fill (cr);
+		}
+	}
+}
+
 void
 clearlooks_draw_button (cairo_t *cr,
                         const ClearlooksColors *colors,
@@ -224,6 +248,7 @@ clearlooks_draw_button (cairo_t *cr,
 //		border_normal = &colors->spot[2];
 	
 	cairo_translate (cr, x, y);
+	cairo_set_line_width (cr, 1.0);
 
 	if (params->xthickness == 3 || params->ythickness == 3)
 	{
@@ -236,10 +261,8 @@ clearlooks_draw_button (cairo_t *cr,
 		if (params->ythickness == 3)
 			yoffset = 1;
 	}
-
-	cairo_set_line_width (cr, 1.0);
 	
-	clearlooks_rounded_rectectangle (cr, xoffset+1, yoffset+1,
+	clearlooks_rounded_rectangle (cr, xoffset+1, yoffset+1,
 	                                     width-(xoffset*2)-2,
 	                                     height-(yoffset*2)-2,
 	                                     3.0, params->corners);
@@ -247,11 +270,11 @@ clearlooks_draw_button (cairo_t *cr,
 	if (!params->active)
 	{
 		cairo_pattern_t *pattern;
-		gdouble shade_size = ((100.0/height)*6.0)/100.0;
+		gdouble shade_size = ((100.0/height)*6.0)/100.0; /* 6 pixels */
 		CairoColor top_shade, bottom_shade, middle_shade;
 		
-		shade (fill, &top_shade, 2.0); // klopt hier iets niet! waarom werkt t met zwart niet!
-		shade (fill, &bottom_shade, 0.85);
+		shade (fill, &top_shade, 1.6);
+		shade (fill, &bottom_shade, 0.80);
 		shade (fill, &middle_shade, 0.96);
 		
 		pattern	= cairo_pattern_create_linear (0, 0, 0, height);
@@ -259,6 +282,12 @@ clearlooks_draw_button (cairo_t *cr,
 		cairo_pattern_add_color_stop_rgb (pattern, shade_size, fill->r, fill->g, fill->b);
 		cairo_pattern_add_color_stop_rgb (pattern, 1.0-shade_size, middle_shade.r, middle_shade.g, middle_shade.b);
 		cairo_pattern_add_color_stop_rgb (pattern, 1.0, bottom_shade.r, bottom_shade.g, bottom_shade.b);
+/*
+		shade (fill, &top_shade, 1.6); 
+		shade (fill, &bottom_shade, 0.75);
+		cairo_pattern_add_color_stop_rgb (pattern, 0.0, top_shade.r, top_shade.g, top_shade.b);
+		cairo_pattern_add_color_stop_rgb (pattern, 1.0, bottom_shade.r, bottom_shade.g, bottom_shade.b);
+*/
 		cairo_set_source (cr, pattern);
 		cairo_fill (cr);
 		cairo_pattern_destroy (pattern);
@@ -271,19 +300,35 @@ clearlooks_draw_button (cairo_t *cr,
 		cairo_fill_preserve (cr);
 
 		pattern	= cairo_pattern_create_linear (0, yoffset+1, 0, 3+yoffset);
-		cairo_pattern_add_color_stop_rgba (pattern, 0.0, 0.0, 0.0, 0.0, params->disabled ? 0.08 : 0.13);
+		cairo_pattern_add_color_stop_rgba (pattern, 0.0, 0.0, 0.0, 0.0, params->disabled ? 0.08 : 0.10);
 		cairo_pattern_add_color_stop_rgba (pattern, 1.0, 0.0, 0.0, 0.0, 0.0);
 		cairo_set_source (cr, pattern);
 		cairo_fill_preserve (cr);
 		cairo_pattern_destroy (pattern);
 
 		pattern	= cairo_pattern_create_linear (xoffset+1, 0, 3+xoffset, 0);
-		cairo_pattern_add_color_stop_rgba (pattern, 0.0, 0.0, 0.0, 0.0, params->disabled ? 0.08 : 0.13);
+		cairo_pattern_add_color_stop_rgba (pattern, 0.0, 0.0, 0.0, 0.0, params->disabled ? 0.08 : 0.10);
 		cairo_pattern_add_color_stop_rgba (pattern, 1.0, 0.0, 0.0, 0.0, 0.0);
 		cairo_set_source (cr, pattern);
 		cairo_fill (cr);
 		cairo_pattern_destroy (pattern);
 	}
+
+
+	/* Drawing the border */
+
+	if (!params->active && params->is_default)
+	{
+		CairoColor *l = &colors->shade[4];
+		CairoColor *d = &colors->shade[4];
+		cairo_set_source_rgb(cr, l->r, l->g, l->b);
+		cairo_rectangle (cr, 2.5, 2.5, width-5, height-5);
+		cairo_stroke (cr);
+
+		cairo_set_source_rgb(cr, d->r, d->g, d->b);
+		cairo_rectangle (cr, 3.5, 3.5, width-7, height-7);
+		cairo_stroke (cr);
+	}
 	
 	if (params->disabled)
 	{
@@ -298,13 +343,12 @@ clearlooks_draw_button (cairo_t *cr,
 		                          border_normal->b);
 	}
 	
-	clearlooks_rounded_rectectangle (cr, xoffset + 0.5, yoffset + 0.5,
-                                     width-(xoffset*2)-1,
-                                     height-(yoffset*2)-1,
-                                     3.0, params->corners);
-	cairo_set_line_width (cr, 1);
+	clearlooks_rounded_rectangle (cr, xoffset + 0.5, yoffset + 0.5,
+                                  width-(xoffset*2)-1, height-(yoffset*2)-1,
+                                  3.0, params->corners);
 	cairo_stroke (cr);
 	
+	/* Draw the "shadow" */
 	if (!params->active)
 	{
 		cairo_translate (cr, 0.5, 0.5);
@@ -316,48 +360,6 @@ clearlooks_draw_button (cairo_t *cr,
 		
 		/* Draw topleft shadow */
 		clearlooks_draw_top_left_highlight (cr, params, width, height, RADIUS);
-
-		if (params->focus)
-		{
-			/* top *//*
-			clearlooks_rounded_rectectangle (cr, xoffset + 1, yoffset + 1,
-                                     width-(xoffset*2)-3,
-                                     height-(yoffset*2)-3,
-                                     2.0, params->corners);
-			
-			cairo_set_source_rgba (cr, colors->spot[0].r, colors->spot[0].g, colors->spot[0].b, 0.7 );
-			cairo_stroke (cr);
-			
-			clearlooks_rounded_rectectangle (cr, xoffset + 2, yoffset + 2,
-                                     width-(xoffset*2)-5,
-                                     height-(yoffset*2)-5,
-                                     1.0, params->corners);
-			cairo_set_source_rgba (cr, colors->spot[1].r, colors->spot[1].g, colors->spot[1].b, 0.7 );
-			cairo_stroke (cr);
-*/
-			/*
-			cairo_move_to (cr, 2.5, 2);
-			cairo_line_to (cr, width-3.5, 2);
-			cairo_set_source_rgba (cr, colors->spot[0].r, colors->spot[0].g, colors->spot[0].b, 0.7 );
-			cairo_stroke (cr);
-			
-			cairo_move_to (cr, 1.5, 3);
-			cairo_line_to (cr, width-2.5, 3);
-			cairo_set_source_rgba (cr, colors->spot[1].r, colors->spot[1].g, colors->spot[1].b, 0.7 );
-			cairo_stroke (cr);
-	
-
-			cairo_move_to (cr, 2.5, height-3);
-			cairo_line_to (cr, width-3.5, height-3);
-			cairo_set_source_rgba (cr, colors->spot[0].r, colors->spot[0].g, colors->spot[0].b, 0.7 );
-			cairo_stroke (cr);
-			
-			cairo_move_to (cr, 1.5, height-4);
-			cairo_line_to (cr, width-2.5, height-4);
-			cairo_set_source_rgba (cr, colors->spot[1].r, colors->spot[1].g, colors->spot[1].b, 0.7 );
-			cairo_stroke (cr);
-			*/
-		}
 	}
 }
 
@@ -400,7 +402,7 @@ clearlooks_draw_entry (cairo_t *cr,
 	if (params->focus)
 	{
 		cairo_rectangle (cr, 2, 2, width-5, height-5);
-	//	clearlooks_rounded_rectectangle (cr, 2, 2, width-5, height-5, RADIUS-1, params->corners);
+	//	clearlooks_rounded_rectangle (cr, 2, 2, width-5, height-5, RADIUS-1, params->corners);
 		cairo_set_source_rgb (cr, colors->spot[0].r, colors->spot[0].g, colors->spot[0].b);
 		cairo_stroke (cr);
 	}
@@ -419,7 +421,7 @@ clearlooks_draw_entry (cairo_t *cr,
 
 	/* Draw the border */
 	cairo_set_source_rgb (cr, border->r, border->g, border->b);
-	clearlooks_rounded_rectectangle (cr, 1, 1, width-3, height-3, RADIUS, params->corners);
+	clearlooks_rounded_rectangle (cr, 1, 1, width-3, height-3, RADIUS, params->corners);
 	cairo_stroke (cr);
 }
 
@@ -453,7 +455,7 @@ clearlooks_draw_spinbutton_down (cairo_t *cr,
 	
 	cairo_translate (cr, x+1, y+1);
 	
-	clearlooks_rounded_rectectangle (cr, 1, 1, width-4, height-4, 3, params->corners);
+	clearlooks_rounded_rectangle (cr, 1, 1, width-4, height-4, 3, params->corners);
 	
 	cairo_set_source_rgb (cr, colors->bg[params->state_type].r,
 	                          colors->bg[params->state_type].g, 
@@ -560,6 +562,105 @@ clearlooks_draw_scale_trough (cairo_t *cr,
 	                                    slider->horizontal);
 }
 
+static void
+clearlooks_draw_slider (cairo_t *cr,
+                        const ClearlooksColors *colors,
+                        const WidgetParameters *params,
+                        int x, int y, int width, int height)
+{
+	const CairoColor	*border = &colors->shade[params->disabled ? 4 : 6];
+	const CairoColor	*spot = &colors->spot[1];
+	CairoColor          *fill = &colors->shade[2];
+	
+
+	cairo_pattern_t *pattern;
+	
+	if (params->disabled)
+		border = &colors->shade[4];
+	else if (params->prelight)
+		border = &colors->spot[2];
+	else
+		border = &colors->shade[6];
+
+	cairo_set_line_width (cr, 1.0);	
+	cairo_translate      (cr, x, y);
+
+	// fill the widget
+	cairo_rectangle (cr, 0.5, 0.5, width-2, height-2);
+
+	/* Fake light */
+	if (!params->disabled)
+	{
+		const CairoColor *top = &colors->shade[0];
+		const CairoColor *bot = &colors->shade[2];
+
+		pattern	= cairo_pattern_create_linear (0, 0, 0, height);
+		cairo_pattern_add_color_stop_rgb (pattern, 0.0,  top->r, top->g, top->b);
+		cairo_pattern_add_color_stop_rgb (pattern, 1.0,  bot->r, bot->g, bot->b);
+		cairo_set_source (cr, pattern);
+		cairo_fill (cr);
+		cairo_pattern_destroy (pattern);
+	}
+	else
+	{
+		cairo_set_source_rgb (cr, fill->r, fill->g, fill->b);
+		cairo_rectangle      (cr, 0.5, 0.5, width-2, height-2);
+		cairo_fill           (cr);
+	}
+
+	/* Set the clip */
+	cairo_save (cr);
+	cairo_rectangle (cr, 0.5, 0.5, 6, height-2);
+	cairo_rectangle (cr, width-7.5, 0.5, 6 , height-2);
+	cairo_clip_preserve (cr);
+	
+	cairo_new_path (cr);
+	
+	/* Draw the handles */
+	clearlooks_rounded_rectangle (cr, 0.5, 0.5, width-1, height-1, 3.0, params->corners);
+	pattern = cairo_pattern_create_linear (0.5, 0.5, 0.5, 0.5+height);
+
+	if ( params->prelight )
+	{
+		CairoColor highlight;
+		shade (spot, &highlight, 1.5);	
+		cairo_pattern_add_color_stop_rgb (pattern, 0.0, highlight.r, highlight.g, highlight.b);
+		cairo_pattern_add_color_stop_rgb (pattern, 1.0, spot->r, spot->g, spot->b);
+		cairo_set_source (cr, pattern);
+	}
+	else
+		cairo_set_source_rgba (cr, 1, 1, 1, 0.5);
+
+	cairo_fill (cr);
+	cairo_pattern_destroy (pattern);
+	
+	cairo_restore (cr);
+
+	/* Draw the border */
+	clearlooks_rounded_rectangle (cr, 0, 0, width-1, height-1, 3.0, params->corners);
+	cairo_set_source_rgb (cr, border->r,
+	                          border->g,
+	                          border->b);
+	cairo_stroke (cr);
+	
+	/* Draw handle lines */
+	if (width > 14)
+	{
+		cairo_move_to (cr, 6, 0.5);
+		cairo_line_to (cr, 6, height-0.5);
+	
+		cairo_move_to (cr, width-7, 0.5);
+		cairo_line_to (cr, width-7, height-0.5);
+	
+		cairo_set_line_width (cr, 1.0);
+		cairo_set_source_rgba (cr, border->r,
+		                           border->g,
+		                           border->b,
+	                           0.3);
+		cairo_stroke (cr);
+	}
+}
+
 void
 clearlooks_draw_slider_button (cairo_t *cr,
                                const ClearlooksColors *colors,
@@ -567,7 +668,8 @@ clearlooks_draw_slider_button (cairo_t *cr,
                                const SliderParameters *slider,
                                int x, int y, int width, int height)
 {
-	CairoColor      *border = (CairoColor*)&colors->shade[6];
+	const CairoColor *border = &colors->shade[6];
+	CairoColor        top, bottom;
 	cairo_pattern_t *pattern;
 
 	cairo_set_line_width (cr, 1.0);
@@ -583,67 +685,10 @@ clearlooks_draw_slider_button (cairo_t *cr,
 	}
 	
 	clearlooks_draw_shadow (cr, width-1, height-1);
-	
-	clearlooks_rounded_rectectangle (cr, 0.5, 0.5, width-2, height-2, 3.0, params->corners);
+	clearlooks_draw_slider (cr, colors, params, 1, 1, width-2, height-2);
 
-	/* Fill the damn thing */
-	cairo_set_source_rgb (cr, colors->bg[params->state_type].r,
-	                          colors->bg[params->state_type].g,
-	                          colors->bg[params->state_type].b);
-	cairo_fill_preserve (cr);
-	
-	/* Fake light */
-	pattern	= cairo_pattern_create_linear (0, 0, 0, 6);
-	cairo_pattern_add_color_stop_rgba (pattern, 0.0,  1.0, 1.0, 1.0, 1.0);
-	cairo_pattern_add_color_stop_rgba (pattern, 1.0,  1.0, 1.0, 1.0, 0.0);
-	cairo_set_source (cr, pattern);
-	cairo_fill (cr);
-	cairo_pattern_destroy (pattern);
-	
-	/* Draw the dented circle */
-	cairo_arc (cr, width-(width/2)-1, height-(height/2)-1, 2.5, 0, M_PI*2);
-	cairo_set_source_rgba (cr, 0., 0., 0., 0.2);
-	cairo_fill (cr);
-
-	cairo_arc (cr, width-(width/2), height-(height/2), 2.5, 0, M_PI*2);
-	cairo_set_source_rgba (cr, 1., 1., 1., 0.4);
-	cairo_fill (cr);
-	
-	/* Set the clip */
-	cairo_rectangle (cr, 1.5, 1.5, 5, height-4);
-	cairo_rectangle (cr, width-7.5, 1.5, 5 , height-4);
-	cairo_clip (cr);
-	
-	cairo_new_path (cr);
-	
-	/* Draw the white handles */
-	clearlooks_rounded_rectectangle (cr, 0.5, 0.5, width-2, height-2, 3.0, params->corners);
-	cairo_set_source_rgba (cr, 1, 1, 1, 0.5);
-	cairo_fill (cr);
-	
-	cairo_reset_clip (cr);
-
-	/* Draw the border */
-	clearlooks_rounded_rectectangle (cr, 1, 1, width-3, height-3, 3.0, params->corners);
-	cairo_set_source_rgb (cr, border->r,
-	                          border->g,
-	                          border->b);
-	cairo_stroke (cr);
-	
-	/* Draw handle lines */
-	cairo_move_to (cr, 7, 1);
-	cairo_line_to (cr, 7, height-1.5);
-	
-	cairo_move_to (cr, width-8, 1);
-	cairo_line_to (cr, width-8, height-1.5);
-	
-	cairo_set_line_width (cr, 1.0);
-	cairo_set_source_rgba (cr, border->r,
-	                           border->g,
-	                           border->b,
-	                           0.1);
-	cairo_stroke (cr);
-}
+	if (width > 24)
+		clearlooks_draw_gripdots (cr, 0, 0, width-2, height-2, 3, 3, 0);}
 
 void
 clearlooks_draw_progressbar_trough (cairo_t *cr,
@@ -670,7 +715,7 @@ clearlooks_draw_progressbar_trough (cairo_t *cr,
 	cairo_fill (cr);
 
 	/* Draw border */
-	clearlooks_rounded_rectectangle (cr, x+0.5, y+0.5, width-1, height-1, 1.5, params->corners);
+	clearlooks_rounded_rectangle (cr, x+0.5, y+0.5, width-1, height-1, 1.5, params->corners);
 	cairo_set_source_rgb (cr, border->r,
 	                          border->g,
 	                          border->b);
@@ -711,9 +756,9 @@ clearlooks_draw_progressbar_fill (cairo_t *cr,
 	cairo_pattern_t *pattern;
 	CairoColor       shade1;
 	
+	/* This is kind of ugly, but I want to get this fixed now. -- Benjamin
+	 * The problem is that the rotation should not be resetted by the save/restore. */
 	cairo_rectangle (cr, x, y, width, height);
-	cairo_clip (cr);
-	cairo_new_path (cr);
 
 	if (is_horizontal)
 	{
@@ -734,6 +779,9 @@ clearlooks_draw_progressbar_fill (cairo_t *cr,
 			rotate_mirror_translate (cr, M_PI/2, x, y+width, TRUE, FALSE);
 	}
 	
+	cairo_save (cr);
+	cairo_clip (cr);
+	
 	stroke_width = height*2;
 
 	x_step = (((float)stroke_width/10)*offset);
@@ -780,12 +828,31 @@ clearlooks_draw_progressbar_fill (cairo_t *cr,
 	
 	cairo_restore (cr);
 	
+	/* inner highlight border */
 	cairo_set_source_rgba (cr, colors->spot[0].r, colors->spot[0].g, colors->spot[0].b, 0.5);
-	cairo_rectangle (cr, 0.5, 0.5, width-2, height-1);
+
+	if (progressbar->pulsing)
+		cairo_rectangle (cr, 1.5, 0.5, width-3, height-1);
+	else
+		cairo_rectangle (cr, 0.5, 0.5, (progressbar->value < 1.0) ? width-2 : width-1, height-1);
+
 	cairo_stroke (cr);
 	
-	cairo_reset_clip (cr);
+	cairo_restore (cr);
 	
+	/* begin of bar line */
+	if (progressbar->pulsing)
+	{
+		cairo_move_to (cr, 0.5, 0);
+		cairo_line_to (cr, 0.5, height);
+		cairo_set_source_rgba (cr, colors->spot[2].r,
+		                           colors->spot[2].g,
+		                           colors->spot[2].b,
+								   0.5);
+		cairo_stroke (cr);
+		
+	}
+
 	/* Left shadow */
 	cairo_translate (cr, width, 0);
 	pattern = cairo_pattern_create_linear (0, 0, 3, 0);
@@ -797,13 +864,16 @@ clearlooks_draw_progressbar_fill (cairo_t *cr,
 	cairo_pattern_destroy (pattern);	
 	
 	/* End of bar line */
-	cairo_move_to (cr, -0.5, 0);
-	cairo_line_to (cr, -0.5, height);
-	cairo_set_source_rgba (cr, colors->spot[2].r,
-	                           colors->spot[2].g,
-	                           colors->spot[2].b,
-							   0.5);
-	cairo_stroke (cr);
+	if (progressbar->value < 1.0)
+	{
+		cairo_move_to (cr, -0.5, 0);
+		cairo_line_to (cr, -0.5, height);
+		cairo_set_source_rgba (cr, colors->spot[2].r,
+		                           colors->spot[2].g,
+		                           colors->spot[2].b,
+								   0.5);
+		cairo_stroke (cr);
+	}
 }
 
 void
@@ -832,14 +902,39 @@ clearlooks_draw_optionmenu (cairo_t *cr,
 }
 
 void
-clearlooks_draw_menubar (cairo_t *cr,
-                         const ClearlooksColors *colors,
-                         const WidgetParameters *params,
-                         int x, int y, int width, int height)
+clearlooks_draw_menubar0 (cairo_t *cr,
+                          const ClearlooksColors *colors,
+                          const WidgetParameters *params,
+                          const MenuBarParameters *menubar,
+                          int x, int y, int width, int height)
+{
+	const CairoColor *light = &colors->shade[0];
+	const CairoColor *dark = &colors->shade[3];
+
+	cairo_set_line_width (cr, 1);
+	cairo_translate (cr, x, y+0.5);
+
+	cairo_move_to (cr, 0, 0);
+	cairo_line_to (cr, width, 0);
+	cairo_set_source_rgb (cr, light->r, light->g, light->b);
+	cairo_stroke (cr);
+
+	cairo_move_to (cr, 0, height-1);
+	cairo_line_to (cr, width, height-1);
+	cairo_set_source_rgb (cr, dark->r, dark->g, dark->b);
+	cairo_stroke (cr);
+}
+
+void
+clearlooks_draw_menubar2 (cairo_t *cr,
+                          const ClearlooksColors *colors,
+                          const WidgetParameters *params,
+                          const MenuBarParameters *menubar,
+                          int x, int y, int width, int height)
 {
 	CairoColor lower;
 	cairo_pattern_t *pattern;
-	
+
 	shade (&colors->bg[0], &lower, 0.95);
 	
 	cairo_translate (cr, x, y);
@@ -867,6 +962,44 @@ clearlooks_draw_menubar (cairo_t *cr,
 	cairo_stroke          (cr);
 }
 
+void
+clearlooks_draw_menubar1 (cairo_t *cr,
+                          const ClearlooksColors *colors,
+                          const WidgetParameters *params,
+                          const MenuBarParameters *menubar,
+                          int x, int y, int width, int height)
+{
+	const CairoColor *border = &colors->shade[3];
+
+	clearlooks_draw_menubar2 (cr, colors, params, menubar,
+	                          x, y, width, height);
+
+	cairo_rectangle      (cr, 0.5, 0.5, width-1, height-1);
+	cairo_set_source_rgb (cr, border->r, border->g, border->b);
+	cairo_stroke         (cr);
+}
+
+
+static menubar_draw_proto menubar_draw[3] = { clearlooks_draw_menubar0, 
+                                              clearlooks_draw_menubar1,
+                                              clearlooks_draw_menubar2 };
+
+void
+clearlooks_draw_menubar (cairo_t *cr,
+                         const ClearlooksColors *colors,
+                         const WidgetParameters *params,
+                         const MenuBarParameters *menubar,
+                         int x, int y, int width, int height)
+{
+
+
+	if (menubar->style < 0 || menubar->style > 3)
+		return;
+
+	menubar_draw[menubar->style](cr, colors, params, menubar,
+	                             x, y, width, height);
+}
+
 static void
 clearlooks_get_frame_gap_clip (int x, int y, int width, int height, 
                                FrameParameters     *frame,
@@ -926,6 +1059,8 @@ clearlooks_draw_frame            (cairo_t *cr,
 	cairo_set_line_width (cr, 1.0);
 	cairo_translate      (cr, x+0.5, y+0.5);
 	
+	/* save everything */
+	cairo_save (cr);
 	/* Set clip for the bevel */
 	if (frame->gap_x != -1)
 	{
@@ -934,7 +1069,6 @@ clearlooks_draw_frame            (cairo_t *cr,
 		cairo_rectangle      (cr, -0.5, -0.5, width, height);
 		cairo_rectangle      (cr, bevel_clip.x, bevel_clip.y, bevel_clip.width, bevel_clip.height);
 		cairo_clip           (cr);
-		cairo_new_path       (cr);
 	}
 	
 	/* Draw the bevel */
@@ -955,8 +1089,9 @@ clearlooks_draw_frame            (cairo_t *cr,
 		clearlooks_draw_highlight_and_shade (cr, &shadow, width, height, RADIUS);
 	}
 	
-	/* Set clip for the frame */
-	cairo_reset_clip     (cr);
+	/* restore the previous clip region */
+	cairo_restore    (cr);
+	cairo_save       (cr);
 	if (frame->gap_x != -1)
 	{
 		/* Set clip for gap */
@@ -964,7 +1099,6 @@ clearlooks_draw_frame            (cairo_t *cr,
 		cairo_rectangle      (cr, -0.5, -0.5, width, height);
 		cairo_rectangle      (cr, frame_clip.x, frame_clip.y, frame_clip.width, frame_clip.height);
 		cairo_clip           (cr);
-		cairo_new_path       (cr);
 	}
 
 	/* Draw frame */
@@ -982,6 +1116,7 @@ clearlooks_draw_frame            (cairo_t *cr,
 		cairo_rectangle      (cr, 0, 0, width-1, height-1);
 	}
 	cairo_stroke         (cr);
+	cairo_restore (cr);
 }
 
 void
@@ -1049,7 +1184,7 @@ clearlooks_draw_tab (cairo_t *cr,
 	
 
 	/* Set tab shape */
-	clearlooks_rounded_rectectangle (cr, 0,
+	clearlooks_rounded_rectangle (cr, 0,
 	                                     0,
 	                                     width-1,
 	                                     height-1,
@@ -1093,7 +1228,7 @@ clearlooks_draw_tab (cairo_t *cr,
 		                                        tab->gap_side == CL_GAP_RIGHT  ? width    : 0,
 		                                        tab->gap_side == CL_GAP_BOTTOM ? height   : 0 );
 	
-		clearlooks_rounded_rectectangle (cr, 0,
+		clearlooks_rounded_rectangle (cr, 0,
 	                                     0,
 	                                     width-1,
 	                                     height-1,
@@ -1109,7 +1244,7 @@ clearlooks_draw_tab (cairo_t *cr,
 	}
 
 	
-	clearlooks_rounded_rectectangle (cr, 0,
+	clearlooks_rounded_rectangle (cr, 0,
 	                                     0,
 	                                     width-1,
 	                                     height-1,
@@ -1241,8 +1376,8 @@ clearlooks_draw_toolbar (cairo_t *cr,
                          const WidgetParameters          *widget,
                          int x, int y, int width, int height)
 {
-	CairoColor *light = (CairoColor*)&colors->shade[0];
-	CairoColor *dark  = (CairoColor*)&colors->shade[3];
+	const CairoColor *light = &colors->shade[0];
+	const CairoColor *dark  = &colors->shade[3];
 	
 	cairo_set_line_width (cr, 1.0);
 	
@@ -1266,16 +1401,28 @@ clearlooks_draw_menuitem (cairo_t *cr,
                           const WidgetParameters          *widget,
                           int x, int y, int width, int height)
 {
-	CairoColor *fill   = (CairoColor*)&colors->spot[1];
-	CairoColor *border = (CairoColor*)&colors->spot[1];
+	CairoColor *fill = (CairoColor*)&colors->spot[1];
+	CairoColor fill_shade;
+	CairoColor *border = (CairoColor*)&colors->spot[2];
+	cairo_pattern_t *pattern;
+	
+	shade (fill, &fill_shade, 0.85);
 	
 	cairo_translate      (cr, x, y);
 	cairo_set_line_width (cr, 1.0);
 	
-	cairo_rectangle      (cr, 0, 0, width, height);
+	clearlooks_rounded_rectangle (cr, 0, 0, width, height, 3.0, widget->corners);
 	
-	cairo_set_source_rgb (cr, fill->r, fill->g, fill->b);
-	cairo_fill           (cr);
+	pattern = cairo_pattern_create_linear (0, 0, 0, height);
+	cairo_pattern_add_color_stop_rgb (pattern, 0,   fill->r, fill->g, fill->b);
+	cairo_pattern_add_color_stop_rgb (pattern, 1.0, fill_shade.r, fill_shade.g, fill_shade.b);
+	
+	cairo_set_source (cr, pattern);
+	cairo_fill_preserve  (cr);
+	cairo_pattern_destroy (pattern);
+	
+	cairo_set_source_rgb (cr, border->r, border->g, border->b);
+	cairo_stroke	         (cr);
 }
 
 void
@@ -1377,7 +1524,7 @@ clearlooks_draw_scrollbar_stepper (cairo_t *cr,
 	cairo_fill (cr);
 	cairo_pattern_destroy (pattern);
 
-	clearlooks_rounded_rectectangle (cr, 0.5, 0.5, width-1, height-1, 3.0, corners);	
+	clearlooks_rounded_rectangle (cr, 0.5, 0.5, width-1, height-1, 3.0, corners);	
 	cairo_set_source_rgb (cr, border->r, border->g, border->b);
 	cairo_stroke (cr);
 	
@@ -1689,3 +1836,34 @@ clearlooks_draw_arrow (cairo_t *cr,
 	_clearlooks_draw_arrow (cr, color, arrow->direction, arrow->type,
 	                        tx, ty, width, height);
 }
+
+void
+clearlooks_draw_resize_grip (cairo_t *cr,
+                             const ClearlooksColors          *colors,
+                             const WidgetParameters          *widget,
+                             const ResizeGripParameters      *grip,
+                             int x, int y, int width, int height)
+{
+ 	CairoColor *dark = (CairoColor*)&colors->shade[4];
+	int lx, ly;
+ 
+	cairo_set_line_width (cr, 1);
+
+	for (ly=0; ly<3; ly++) // vertically, three rows of dots
+	{
+		for (lx=0; lx<=ly; lx++) // horizontally
+		{
+			int ny = (2-ly) * 5;
+			int nx = lx * 4;
+
+			cairo_set_source_rgb (cr, dark->r, dark->g, dark->b);
+			cairo_arc (cr, x+width-nx-1, y+height-ny-1, 1.3, 0, M_PI*2);
+			cairo_fill (cr);
+
+			cairo_set_source_rgba (cr, 1, 1, 1, 0.5);
+			cairo_arc (cr, x+width-nx, y+height-ny, 1.3, 0, M_PI*2);
+			cairo_fill (cr);
+		}
+	}
+}
+
