@@ -1,6 +1,8 @@
 #ifndef CLEARLOOKS_TYPES_H
 #define CLEARLOOKS_TYPES_H
 
+#include <ge-support.h>
+
 typedef unsigned char boolean;
 typedef unsigned char uint8;
 
@@ -96,12 +98,17 @@ typedef enum
 	CL_PROGRESSBAR_DISCRETE
 } ClearlooksProgressBarStyle;
 
-typedef struct
+typedef enum
 {
-	double r;
-	double g;
-	double b;
-} CairoColor;
+	CL_WINDOW_EDGE_NORTH_WEST,
+	CL_WINDOW_EDGE_NORTH,
+	CL_WINDOW_EDGE_NORTH_EAST,
+	CL_WINDOW_EDGE_WEST,
+	CL_WINDOW_EDGE_EAST,
+	CL_WINDOW_EDGE_SOUTH_WEST,
+	CL_WINDOW_EDGE_SOUTH,
+	CL_WINDOW_EDGE_SOUTH_EAST  
+} ClearlooksWindowEdge;
 
 typedef struct
 {
@@ -118,7 +125,6 @@ typedef struct
 	
 	CairoColor shade[9];
 	CairoColor spot[3];
-	
 } ClearlooksColors;
 
 typedef struct
@@ -127,6 +133,8 @@ typedef struct
 	boolean prelight;
 	boolean disabled;
 	boolean focus;
+	boolean is_default;
+	boolean rtl;
 	
 	ClearlooksStateType state_type;
 	
@@ -148,6 +156,8 @@ typedef struct
 {
 	ClearlooksOrientation orientation;
 	ClearlooksProgressBarStyle style;
+	boolean pulsing;
+	float value;
 } ProgressBarParameters;
 
 typedef struct
@@ -212,6 +222,16 @@ typedef struct
 	ClearlooksDirection direction;
 } ArrowParameters;
 
+typedef struct
+{
+	ClearlooksWindowEdge edge;
+} ResizeGripParameters;
+
+typedef struct
+{
+	int style;
+} MenuBarParameters;
+
 #define CLEARLOOKS_RECTANGLE_SET(rect, _x, _y, _w, _h) rect.x      = _x; \
                                                        rect.y      = _y; \
                                                        rect.width  = _w; \
