@@ -1,9 +1,10 @@
 #include <gtk/gtkstyle.h>
+#include "ge-support.h"
 
 typedef struct _MistStyle MistStyle;
 typedef struct _MistStyleClass MistStyleClass;
 
-extern GType mist_type_style G_GNUC_INTERNAL;
+extern GType mist_type_style;
 
 #define MIST_TYPE_STYLE              mist_type_style
 #define MIST_STYLE(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), MIST_TYPE_STYLE, MistStyle))
@@ -15,6 +16,8 @@ extern GType mist_type_style G_GNUC_INTERNAL;
 struct _MistStyle
 {
   GtkStyle parent_instance;
+
+  CairoColorCube color_cube;
 };
 
 struct _MistStyleClass
@@ -24,4 +27,3 @@ struct _MistStyleClass
 
 void mist_style_register_type (GTypeModule *module) G_GNUC_INTERNAL;
 
-
